@@ -338,7 +338,7 @@ insert_html (GtkWidget *mi, GtkHTMLControlData *cd)
                 (*items)++; items_sep++
 
 #define ADD_ITEM(l,f,t) \
-		menuitem = gtk_menu_item_new_with_label (l); \
+		menuitem = gtk_menu_item_new_with_mnemonic (l); \
                 ADD_ITEM_BASE (f,t)
 
 #define ADD_ITEM_MNEMONIC(l,f,t) \
@@ -447,7 +447,7 @@ prepare_properties_and_menu (GtkHTMLControlData *cd, guint *items, guint *props)
 
 	if (cd->format_html) {
 		ADD_SEP;
-		ADD_ITEM (_("Insert Link"), insert_link, NONE);
+		ADD_ITEM (_("Insert _Link"), insert_link, NONE);
 		if (((active && html_engine_selection_contains_link (e))
 		     || (obj
 			 && (HTML_OBJECT_TYPE (obj) == HTML_TYPE_LINKTEXT
@@ -585,8 +585,9 @@ prepare_properties_and_menu (GtkHTMLControlData *cd, guint *items, guint *props)
 					      GTK_MENU_SHELL (menu));
 	END_SUBMENU;
 
+	g_object_ref_sink (menu);
 	if (*items == 0) {
-		g_object_ref_sink (menu);
+		g_object_unref (menu);
 		menu = NULL;
 	} else
 		gtk_widget_show (menu);
@@ -606,6 +607,9 @@ popup_show (GtkHTMLControlData *cd, GdkEventButton *event)
 		gtk_menu_popup (GTK_MENU (menu), NULL, NULL, NULL, NULL,
 				event ? event->button : 0, event ? event->time : 0);
 
+	if (menu)
+		g_object_unref (menu);
+
 	return (items > 0);
 }
 
@@ -629,10 +633,13 @@ popup_show_at_cursor (GtkHTMLControlData *cd)
 	guint items, props;
 
 	menu = prepare_properties_and_menu (cd, &items, &props);
-	gtk_widget_show (menu);
+
 	if (items)
 		gtk_menu_popup (GTK_MENU (menu), NULL, NULL, set_position, cd, 0, 0);
 
+	if (menu)
+		g_object_unref (menu);
+
 	return (items > 0);
 }
 
@@ -643,7 +650,10 @@ property_dialog_show (GtkHTMLControlData *cd)
 	guint items, props;
 
 	menu = prepare_properties_and_menu (cd, &items, &props);
-	g_object_ref_sink (menu);
+
+	if (menu)
+		g_object_unref (menu);
+
 	if (props)
 		show_prop_dialog (cd, GTK_HTML_EDIT_PROPERTY_NONE);
 }
